import tkinter as tk
from tkinter import ttk, filedialog, messagebox, scrolledtext, Canvas
import pandas as pd
import smtplib
import os
from dotenv import load_dotenv
from email.mime.text import MIMEText
from email.mime.multipart import MIMEMultipart

# 환경 변수 로드
load_dotenv("myEmail.env")
EMAIL_ADDRESS = os.getenv("EMAIL_USER")
EMAIL_PASSWORD = os.getenv("EMAIL_PASS")

# 이메일 리스트 저장할 전역 변수
emails = []
email_vars = []
email_frame_inner = None  # 글로벌로 선언된 email_frame_inner

# 이메일 전송 함수
def send_email(subject, body, recipients):
    if not EMAIL_ADDRESS or not EMAIL_PASSWORD:
        messagebox.showerror("오류", "이메일 계정 정보가 설정되지 않았습니다.")
        return

    try:
        with smtplib.SMTP('smtp.gmail.com', 587) as server:
            server.starttls()
            server.login(EMAIL_ADDRESS, EMAIL_PASSWORD)

            failed_emails = []
            for email in recipients:
                try:
                    msg = MIMEMultipart()
                    msg['From'] = EMAIL_ADDRESS
                    msg['To'] = email
                    msg['Subject'] = subject
                    msg.attach(MIMEText(body, 'plain'))
                    server.sendmail(EMAIL_ADDRESS, email, msg.as_string())
                except Exception as e:
                    failed_emails.append((email, str(e)))

            if failed_emails:
                error_msg = "\n".join([f"{email}: {error}" for email, error in failed_emails])
                messagebox.showwarning("일부 이메일 실패", f"다음 이메일 전송 실패:\n{error_msg}")
            else:
                messagebox.showinfo("성공", "이메일이 성공적으로 발송되었습니다.")
    except Exception as e:
        messagebox.showerror("오류", f"이메일 전송 실패: {e}")

# 엑셀 파일 열기 및 이메일 목록 표시
def open_file():
    global emails, email_vars, email_frame_inner
    file_path = filedialog.askopenfilename(filetypes=[("Excel files", "*.xlsx")])
    if file_path:
        try:
            df = pd.read_excel(file_path)
            emails = df['Email'].dropna().tolist()  # 'Email' 열 가져오기
            
            # 기존 위젯 삭제
            if email_frame_inner:
                email_frame_inner.destroy()  # email_frame_inner가 존재하면 삭제

            email_vars.clear()
            display_emails(emails)

            messagebox.showinfo("파일 열기 성공", f"{len(emails)}개의 이메일을 찾았습니다.")
        except Exception as e:
            messagebox.showerror("오류", f"엑셀 파일을 읽는 중 오류 발생: {e}")

# 선택된 이메일 발송 함수
def send_selected_emails():
    subject = subject_entry.get()
    body = body_text.get("1.0", tk.END).strip()
    recipients = [email for email, var in zip(emails, email_vars) if var.get()]

    if not recipients:
        messagebox.showwarning("선택 오류", "보낼 이메일을 선택해 주세요.")
        return

    send_email(subject, body, recipients)

# 이메일 리스트를 10개씩 그리드 형태로 표시 (스크롤 포함)
def display_emails(email_list):
    global email_frame_inner  # email_frame_inner를 글로벌 변수로 선언

    email_canvas.delete("all")  # 기존 캔버스 내용 삭제

    email_frame_inner = ttk.Frame(email_canvas)  # 새로 프레임을 생성
    email_canvas.create_window((0, 0), window=email_frame_inner, anchor="nw")

    email_vars.clear()
    row, col = 0, 0
    for i, email in enumerate(email_list):
        var = tk.BooleanVar()
        email_vars.append(var)

        chk = ttk.Checkbutton(email_frame_inner, text=email, variable=var)
        chk.grid(row=row, column=col, sticky="w", padx=5, pady=2)

        col += 1
        if col >= 2:  # 2개씩 한 줄
            col = 0
            row += 1

    email_frame_inner.update_idletasks()
    email_canvas.config(scrollregion=email_canvas.bbox("all"))

# GUI 설정
root = tk.Tk()
root.title("이메일 발송기")
root.geometry("500x500")

style = ttk.Style()
style.configure("TButton", font=("Arial", 10), padding=5)
style.configure("TLabel", font=("Arial", 10))
style.configure("TEntry", font=("Arial", 10), padding=5)

# 메인 프레임
main_frame = ttk.Frame(root, padding=10)
main_frame.pack(fill="both", expand=True)

# 이메일 제목
ttk.Label(main_frame, text="이메일 제목").pack(anchor="w")
subject_entry = ttk.Entry(main_frame, width=50)
subject_entry.pack(fill="x", pady=2)

# 이메일 내용
ttk.Label(main_frame, text="이메일 내용").pack(anchor="w")
body_text = scrolledtext.ScrolledText(main_frame, width=50, height=5)
body_text.pack(fill="both", pady=2)

# 이메일 리스트 프레임 (스크롤 포함)
email_list_container = ttk.LabelFrame(main_frame, text="이메일 리스트")
email_list_container.pack(fill="both", expand=True, pady=5)

email_canvas = Canvas(email_list_container, height=150)
email_canvas.pack(side="left", fill="both", expand=True)

scrollbar = ttk.Scrollbar(email_list_container, orient="vertical", command=email_canvas.yview)
scrollbar.pack(side="right", fill="y")

email_canvas.configure(yscrollcommand=scrollbar.set)
email_frame_inner = ttk.Frame(email_canvas)
email_canvas.create_window((0, 0), window=email_frame_inner, anchor="nw")

# 버튼 영역
button_frame = ttk.Frame(main_frame)
button_frame.pack(fill="x", pady=5)

ttk.Button(button_frame, text="엑셀 파일 열기", command=open_file).pack(side="left", expand=True, padx=5)
ttk.Button(button_frame, text="이메일 발송", command=send_selected_emails).pack(side="right", expand=True, padx=5)

# 실행
root.mainloop()
